@@ -34,7 +34,11 @@ def user_model(model_base):
 
 @fixture()
 def engine(user_model) -> Engine:
-    engine: Engine = create_engine("sqlite:///:memory:", poolclass=QueuePool, connect_args={"check_same_thread": False})
+    engine: Engine = create_engine(
+        "sqlite:///:memory:",
+        poolclass=QueuePool,
+        connect_args={"check_same_thread": False},
+    )
     user_model.metadata.create_all(engine)
     yield engine
 
@@ -103,5 +107,14 @@ def register_schema_routes(schema_api: SchemaAPI, user_list, user_detail):
 
 @fixture()
 def generate_data():
-    generate_data = lambda user: {"type": "user", "id": user.id, "attributes": {"name": user.name, "age": user.age}}
-    return generate_data
+    def _generate_data(user, only_fields=None):
+        if only_fields is not None:
+            attributes = {field: getattr(user, field) for field in only_fields}
+        else:
+            attributes = {
+                "name": user.name,
+                "age": user.age,
+            }
+        return {"type": "user", "id": user.id, "attributes": attributes}
+
+    return _generate_data
